#!/bin/bash
# © Copyright [2016 - 2020] Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates and licensors
# (“Micro Focus”) are as may be set forth in the express warranty statements accompanying such
# products and services. Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial errors or omissions
# contained herein. The information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential information
# and a valid license is required for possession, use or copying. If this work is provided to the
# U.S. Government, consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items are licensed
# to the U.S. Government under vendor's standard commercial license.

BRIDGE_SUBNET=""
BRIDGE_NAME=""
if [[ $# -eq 0 || -z $1 ]]; then
	logger -t cis "Invalid argument."
	exit 1
fi
UNIT_NAME=$1
if [ -f /etc/opt/novell/cis/$UNIT_NAME/VERSION ]; then
	exit 0
fi
if [ $# -gt 1 ];then
	if  ! [[ $2 =~ ^[0-9]+$ ]]; then  # && [[ $2 -gt 0 ]]; then
		logger -t cis "Argument '$2' is not valid port"
		exit 1;
	else
		if [[ $2 -lt 1 || $2 -gt 65535 ]]; then
			logger -t cis "Argument '$2' is not valid port"
			exit 1;
		fi
	fi
	if [ $# -eq 3 ];then
		if  ! [[ $3 =~ ^[0-9]+$ ]]; then  # && [[ $3 -gt 0 ]]; then
			logger -t cis "Argument '$3' is not valid port"
			exit 1;
		else
			if [[ $3 -lt 1 || $3 -gt 65535 ]]; then
	       		logger -t cis "Argument '$3' is not valid port"
			exit 1;
			fi
		fi
	fi
fi
PORT1=$2
PORT2=$3
MODIFIED="no"
BRIDGE_NAME=`docker network inspect bridge | grep -e 'com.docker.network.bridge.name' | cut -d':' -f2 | sed 's/[",[:space:]]//g'`
if [ -z $BRIDGE_NAME ]; then
	logger -t cis "Unable to get docker default bridge name.\n"
	exit 1;
fi
BRIDGE_SUBNET=`docker network inspect bridge | grep -e Subnet | cut -d':' -f2 | sed 's/[",[:space:]]//g'`
if [ -z $BRIDGE_SUBNET ]; then
        logger -t cis "Unable to get docker default bridge subnet.\n"
	exit 1;
fi
yast2 firewall interfaces show 2>&1 | grep "INT[[:space:]].*$BRIDGE_NAME"
if [ $? -ne 0 ]; then
	yast2 firewall interfaces add interface=$BRIDGE_NAME zone=INT
	yast2 firewall interfaces show 2>&1 | grep "INT[[:space:]].*$BRIDGE_NAME"
	if [ $? -ne 0 ]; then
		logger -t cis "Unable to add docker default bridge to firewall INT zone.\n"
		exit 1;
	fi
	MODIFIED="yes"
fi

grep '^\s*FW_MASQUERADE\s*=' /etc/sysconfig/SuSEfirewall2 | grep 'yes'
OUT1=$?
grep '^\s*FW_ROUTE\s*=' /etc/sysconfig/SuSEfirewall2 | grep 'yes'
OUT2=$?
if [[ $OUT1 -ne 0 || $OUT2 -ne 0 ]]; then
        yast2 firewall masquerade enable
        grep '^\s*FW_MASQUERADE\s*=' /etc/sysconfig/SuSEfirewall2 | grep 'yes'
        OUT1=$?
        grep '^\s*FW_ROUTE\s*=' /etc/sysconfig/SuSEfirewall2 | grep 'yes'
        OUT2=$?
        if [[ $OUT1 -ne 0 || $OUT2 -ne 0 ]]; then
                logger -t cis "Unable to enable Masquerading in firewall.\n"
                exit 1;
        fi
        MODIFIED="yes"
fi

grep '^\s*FW_STOP_KEEP_ROUTING_STATE\s*=' /etc/sysconfig/SuSEfirewall2 | grep 'yes'
if [ $? -ne 0 ]; then
	grep '^\s*FW_STOP_KEEP_ROUTING_STATE\s*=' /etc/sysconfig/SuSEfirewall2
	if [ $? -ne 0 ]; then
		echo "FW_STOP_KEEP_ROUTING_STATE=\"\"" >> /etc/sysconfig/SuSEfirewall2
	fi
	sed -i -e "s|^\s*\(FW_STOP_KEEP_ROUTING_STATE\)\(\s*=\s*\"\)\(.*\)\"|\1=\"yes\"|g" /etc/sysconfig/SuSEfirewall2
	grep '^\s*FW_STOP_KEEP_ROUTING_STATE\s*=' /etc/sysconfig/SuSEfirewall2 | grep 'yes'
	if [ $? -ne 0 ]; then
		logger -t cis "Unable to enable IP routing FW_STOP_KEEP_ROUTING_STATE  in firewall.\n"
	fi
fi
SED_BRIDGE_SUBNET=\'$BRIDGE_SUBNET\'
grep '^\s*FW_MASQ_NETS\s*=' /etc/sysconfig/SuSEfirewall2 | grep $BRIDGE_SUBNET
if [ $? -ne 0 ]; then
	grep '^\s*FW_MASQ_NETS\s*=' /etc/sysconfig/SuSEfirewall2
	if [ $? -ne 0 ]; then
		echo "FW_MASQ_NETS=\"\"" >> /etc/sysconfig/SuSEfirewall2
	fi

	sed -i -e "s|^\s*\(FW_MASQ_NETS\)\(\s*=\s*\"\)\(.*\)\"|\1=\"\3 $BRIDGE_SUBNET \"|g" /etc/sysconfig/SuSEfirewall2
	grep '^\s*FW_MASQ_NETS\s*=' /etc/sysconfig/SuSEfirewall2 | grep $BRIDGE_SUBNET
        if [ $? -ne 0 ]; then
                logger -t cis "Unable to allow docker network Masquerading in firewall.\n"
                exit 1;
        fi
	MODIFIED="yes"
fi
if [ $# -gt 1 ];then
	FW_FORWARD_ENTRY="0/0,$BRIDGE_SUBNET,tcp,$PORT1"
	grep '^\s*FW_FORWARD\s*=' /etc/sysconfig/SuSEfirewall2 | grep $FW_FORWARD_ENTRY
	if [ $? -ne 0 ]; then
		grep '^\s*FW_FORWARD\s*=' /etc/sysconfig/SuSEfirewall2
		if [ $? -ne 0 ]; then
			echo "FW_FORWARD=\"\"" >> /etc/sysconfig/SuSEfirewall2
		fi

		sed -i -e "s|^\s*\(FW_FORWARD\)\(\s*=\s*\"\)\(.*\)\"|\1=\"\3 $FW_FORWARD_ENTRY \"|g" /etc/sysconfig/SuSEfirewall2
		grep '^\s*FW_FORWARD\s*=' /etc/sysconfig/SuSEfirewall2 | grep $FW_FORWARD_ENTRY
        	if [ $? -ne 0 ]; then
                	logger -t cis "Unable to add port forwarding setting in firewall.\n"
	                exit 1;
        	fi
		MODIFIED="yes"
	fi
	yast2 firewall services show detailed zone=EXT 2>&1 | grep 'TCP' | grep $PORT1
	if [ $? -ne 0 ]; then
        	yast2 firewall services add tcpport=$PORT1 zone=EXT
	        yast2 firewall services show detailed zone=EXT 2>&1 | grep 'TCP' | grep $PORT1
        	if [ $? -ne 0 ]; then
                	logger -t cis "Unable to open port $PORT1 in firewall EXT zone.\n"
	                exit 1;
        	fi
		MODIFIED="yes"
	fi
	if [ $# -eq 3 ];then
        	FW_FORWARD_ENTRY="0/0,$BRIDGE_SUBNET,tcp,$PORT2"
        	grep '^\s*FW_FORWARD\s*=' /etc/sysconfig/SuSEfirewall2 | grep $FW_FORWARD_ENTRY
	        if [ $? -ne 0 ]; then
        	        sed -i -e "s|^\s*\(FW_FORWARD\)\(\s*=\s*\"\)\(.*\)\"|\1=\"\3 $FW_FORWARD_ENTRY \"|g" /etc/sysconfig/SuSEfirewall2
                	grep '^\s*FW_FORWARD\s*=' /etc/sysconfig/SuSEfirewall2 | grep $FW_FORWARD_ENTRY
	                if [ $? -ne 0 ]; then
        	                logger -t cis "Unable to add port forwarding setting in firewall.\n"
                	        exit 1;
                	fi
			MODIFIED="yes"
        	fi
	        yast2 firewall services show detailed zone=EXT 2>&1 | grep 'TCP' | grep $PORT2
        	if [ $? -ne 0 ]; then
                	yast2 firewall services add tcpport=$PORT2 zone=EXT
	                yast2 firewall services show detailed zone=EXT 2>&1 | grep 'TCP' | grep $PORT2
        	        if [ $? -ne 0 ]; then
                	        logger -t cis "Unable to open port $PORT2 in firewall EXT zone.\n"
                        	exit 1;
	                fi
			MODIFIED="yes"
        	fi
	fi
fi
if [ $MODIFIED = "yes" ];then
	systemctl status SuSEfirewall2.service
	if [ $? -eq 0 ]; then
		systemctl restart SuSEfirewall2.service
	fi
fi
if [ $UNIT_NAME = "zk" ]; then
rpm -q --queryformat "%{VERSION} %{RELEASE}\n" oes-cis-zookeeper-docker-image >/etc/opt/novell/cis/$UNIT_NAME/VERSION
elif [ $UNIT_NAME = "kafka" ]; then
rpm -q --queryformat "%{VERSION} %{RELEASE}\n" oes-cis-$UNIT_NAME-docker-image >/etc/opt/novell/cis/$UNIT_NAME/VERSION
elif [ $UNIT_NAME = "elastic" ]; then
rpm -q --queryformat "%{VERSION} %{RELEASE}\n" oes-cis-$UNIT_NAME-docker-image >/etc/opt/novell/cis/es/VERSION
fi
