#!/bin/sh
# © Copyright [2018 - 2020] Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates and licensors
# (“Micro Focus”) are as may be set forth in the express warranty statements accompanying such
# products and services. Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial errors or omissions
# contained herein. The information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential information
# and a valid license is required for possession, use or copying. If this work is provided to the
# U.S. Government, consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items are licensed
# to the U.S. Government under vendor's standard commercial license.

precheck() {
    /usr/bin/docker inspect ${ZK_NAME} 2>/dev/null
    if [ $? -eq 0 ]; then
        if [[ ${SECURE_MODE} == "yes" ]]; then
            /usr/bin/docker stop ${ZK_ENVOY_NAME} 2>/dev/null
            /usr/bin/docker stop ${ZK_NAME} 2>/dev/null
        else
            /usr/bin/docker stop ${ZK_NAME} 2>/dev/null
        fi
        sleep 2
        /usr/bin/docker inspect ${ZK_NAME} 2>/dev/null
        if [ $? -eq 0 ]; then
            /usr/bin/docker rm -f ${ZK_ENVOY_NAME} 2>/dev/null
            /usr/bin/docker rm -f ${ZK_NAME} 2>/dev/null
        fi
    fi
}

start() {

    #precheck
    precheck

    # Enable Zookeeper port
    /bin/bash /opt/novell/cis/zk/bin/cis_enable_firewall.sh zk ${ZK_PORT}

    # Add an empty snapshot file if there are no snapshots (possible only for zk version older than 3.5.7)
    SNAPSHOT_FILE="$(find $ZK_DATA_PATH -name snapshot* | sort | tail -1)"
    if [[ (-z $SNAPSHOT_FILE) || (! -e $SNAPSHOT_FILE) ]]; then
        VERSION_FOLDER="$(find $ZK_DATA_PATH -name version* | sort | tail -1)"
        if [[ (-z $VERSION_FOLDER) || (! -d $VERSION_FOLDER) ]]; then
            VERSION_FOLDER="$ZK_DATA_PATH/version-2"
            mkdir -p $VERSION_FOLDER
        fi
        mv /etc/opt/novell/cis/zk/snapshot.0 $VERSION_FOLDER
    elif [[ -e /etc/opt/novell/cis/zk/snapshot.0 ]]; then
        rm /etc/opt/novell/cis/zk/snapshot.0
    fi

    if [[ ${SECURE_MODE} == "yes" ]]; then

   		BRIDGE_NAME=`docker network inspect bridge | grep -e 'com.docker.network.bridge.name' | cut -d':' -f2 | sed 's/[",[:space:]]//g'`
		if [ -z $BRIDGE_NAME ]; then
				logger -t cis "Unable to get docker default bridge name.\n"
				exit 1;
		fi
		BRIDGE_GATEWAY=`docker network inspect bridge | grep -e Gateway | cut -d':' -f2 | sed 's/[",[:space:]]//g'`
		if [ -z $BRIDGE_GATEWAY ]; then
				logger -t cis "Unable to get docker default bridge subnet.\n"
				exit 1;
		fi

		sed -i "s/{address}/${BRIDGE_GATEWAY}/g" ${ZK_ENVOY_CONF_PATH}
		sed -i "s/{zk_port}/${ZK_PORT}/g" ${ZK_ENVOY_CONF_PATH}
		sed -i "s/{zk_secure_port}/${ZK_SECURE_PORT}/g" ${ZK_ENVOY_CONF_PATH}

        /usr/bin/docker run --rm -p ${ZK_SECURE_PORT}:2181 -v /etc/localtime:/etc/localtime:ro -v ${ZK_DATALOG_PATH}:/datalog -v ${ZK_DATA_PATH}:/data -v /etc/opt/novell/cis/zk/log4j.properties:/conf/log4j.properties -v /opt/novell/cis/zk/bin/docker-entrypoint.sh:/docker-entrypoint.sh -e JVMFLAGS="-Xmx512m" -e "ZOO_LOG4J_PROP=WARN,CONSOLE" -e "ZOO_ADMINSERVER_ENABLED=false" -e "ZOO_MAX_CLIENT_CNXNS=120" --name ${ZK_NAME} zookeeper:3.5.7 &

        /usr/bin/docker run --rm -v ${SERVER_CERTS_PATH}:/home -v ${ZK_ENVOY_CONF_PATH}:/etc/envoy/envoy.yaml --name ${ZK_ENVOY_NAME} -p ${ZK_PORT}:${ZK_PORT} envoyproxy/envoy:v1.14.1 &
    else
        /usr/bin/docker run --rm -p ${ZK_PORT}:2181 -v /etc/localtime:/etc/localtime:ro -v ${ZK_DATALOG_PATH}:/datalog -v ${ZK_DATA_PATH}:/data -v /etc/opt/novell/cis/zk/log4j.properties:/conf/log4j.properties -v /opt/novell/cis/zk/bin/docker-entrypoint.sh:/docker-entrypoint.sh --name ${ZK_NAME} zookeeper:3.5.7 &
    fi
}

stop() {
    if [[ ${SECURE_MODE} == "yes" ]]; then
        /usr/bin/docker stop ${ZK_ENVOY_NAME}
        /usr/bin/docker stop ${ZK_NAME}
    else
        /usr/bin/docker stop ${ZK_NAME}
    fi
}

load() {
    /usr/bin/docker load -i /var/opt/novell/cis/envoy.tar.gz
    /usr/bin/docker load -i /var/opt/novell/cis/zookeeper.tar.gz
    docker rmi $(docker images --filter "reference=envoy:1.7" -q) > /dev/null 2>&1
    docker rmi $(docker images --filter "reference=envoy:1.7.0" -q) > /dev/null 2>&1
    docker rmi $(docker images --filter "reference=envoyproxy/envoy" --filter "before=envoyproxy/envoy:v1.14.1" -q) > /dev/null 2>&1
    docker rmi $(docker images --filter "reference=envoyproxy/envoy" --filter "since=envoyproxy/envoy:v1.14.1" -q) > /dev/null 2>&1

    docker rmi $(docker images --filter "reference=zookeeper" --filter "before=zookeeper:3.5.7" -q) > /dev/null 2>&1
    docker rmi $(docker images --filter "reference=zookeeper" --filter "since=zookeeper:3.5.7" -q) > /dev/null 2>&1
    exit 0
}

case "$1" in
    start)
        start
        ;;
    stop)
        stop
        ;;
	load)
		load
		;;
esac
